/*
  File: Controller.m
  Authors: Eric Bergerson
  Modification History:

  Created 2/4/91

  Copyright (c) 1991 Objective Technologies, Inc.
  All Rights Reserved.
*/

#import "Controller.h"
#import <appkit/appkit.h>
#import <otikit/smartkit.h>
#import <time.h>

@implementation Controller

- appDidInit:sender
{
  id dateCell,text;
  long aClock;
  struct tm *timedat;
  
  /* initialize the date field to today */
  aClock = time(0);
  timedat = localtime(&aClock );
  dateCell = [date cell];
  [dateCell setDateValue:(long) timedat->tm_mon 
   :(long) timedat->tm_mday :(long) timedat->tm_year];

  /* don't let the tape wrap the orders */
  text = [tape docView];
  [text setNoWrap];

  /* start application within the name field selected */
  [name selectText:self];

  return self;
}

- total:sender
{
  double q,p,t;

  q = [quantity doubleValue];
  p = [price doubleValue];
  t = p * q;
  [total setDoubleValue:t];

  return self;
}

- enter:sender
{
  char buf[1000];
  id text;
  int len;

  [self total: self];
  sprintf(buf,"%8s  %20s  %3d-%3d-%4d  %25s  %15d  %8.2lf  %15.2lf\n",
	  [date stringValue],
	  [name stringValue],
	  [areaCode intValue],
	  [exchange intValue],
	  [number intValue],
	  [item stringValue],
	  [quantity intValue],
	  [price doubleValue],
	  [total doubleValue]);

  text = [tape docView];
  len = [text textLength];
  [text setSel:len+1:len+1];
  [text replaceSel:buf];
  [text hideCaret];

  return self;
}

- (BOOL) errorDidOccur:(int) errNum from:sender
{
  char msg[500];
  char areacode[10];
  const char *contents;
  int i,len;
  id rangelist;

  switch(errNum){
  case SF_BADLENMIN:
    contents = [sender stringValue];
    if(contents == NULL || strlen(contents) == 0)
      return YES;
    sprintf(msg,
	    "The Entry:\n"
	    "%s\n"
	    "is too short.  It may only consist of"
	    " %d characters",
	    [sender stringValue],
	    [sender maxChars]);
    break;
  case SF_BADLENMAX:
    sprintf(msg,
	    "The Entry:\n"
	    "%s\n"
	    "is too long.  It may only consist of"
	    " %d characters",
	    [sender stringValue],
	    [sender maxChars]);
    break;
  case SF_BADLIST:
    sprintf(msg,
	    "The area code you entered is invalid.\n"
	    "It must be one of the following:\n\n");
    rangelist = [sender rangeList];
    len = [rangelist count];
    for(i=0; i<len; i++){
      sprintf(areacode,"%s  ",[[rangelist objectAt:i] stringValue]);
      strcat(msg,areacode);
    }
    break;
  default:
    return YES;
  }

  [sender showError: msg];

  return NO;
}

  
@end
